/*
 * CustomProgressHUDView.m
 * Created on July 26, 2016
 *
 * Copyright (c) 2014, NETGEAR, Inc.
 * 350 East Plumeria, San Jose California, 95134, U.S.A.
 * All rights reserved.
 *
 *
 * This software is the confidential and proprietary information of
 * NETGEAR, Inc. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with NETGEAR.
 *
 * @author VVDN
 *
 */

#import "CustomProgressHUDView.h"
#import "AppDelegate.h"
#import "Constants.h"
#import "CommonMethods.h"
#import "LocalisedLabel.h"

@implementation CustomProgressHUDView {
    UIView* parentView;
}
@synthesize progressView, coverView, indeterminateProgress, window;

/**
 * @method - showMDProgressWithMessage
 * @description - to show View with MDProgressHUD and a label
 * @param - message
 * @return None
 */
+ (CustomProgressHUDView*)getInstance {
    static CustomProgressHUDView *customProgressHUD = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        customProgressHUD = [[self alloc] init];
    });
    return customProgressHUD;
}

-(void)showMDProgressWithMessage: (NSString *)message WithTitle: (NSString *)title {
    UILabel *titleLabel, *messageLabel;
    coverView = [[UIView alloc]initWithFrame: CGRectMake(0, 0, [UIScreen mainScreen].bounds.size.width, [UIScreen mainScreen].bounds.size.height)];
    coverView.backgroundColor = [UIColor colorWithRed:0/255.0 green:0/255.0 blue:0/255.0 alpha:0.4];
    UIView *coverSubView;
    //if title is not provided for progress view, load nib for progress view without title label
    if(title.length == 0) {
        NSArray *nibArray = [[NSBundle mainBundle]loadNibNamed:@"ProgressHUDWithNoTitle" owner:self options:nil];
        coverSubView = [nibArray objectAtIndex:0];
        indeterminateProgress = [coverSubView viewWithTag:100];
        messageLabel = [coverSubView viewWithTag:101];
        messageLabel.text = message;
        coverSubView.translatesAutoresizingMaskIntoConstraints = YES;
        [coverSubView setFrame:CGRectMake(0, 0, [UIScreen mainScreen].bounds.size.width, [UIScreen mainScreen].bounds.size.height)];
    }
    //if title is provided for progress view, load nib for progress view with title label
    else {
        NSArray *nibArray = [[NSBundle mainBundle]loadNibNamed:@"ProgressHUDWithTitle" owner:self options:nil];
        coverSubView = [nibArray objectAtIndex:0];
        titleLabel = [coverSubView viewWithTag:100];
        titleLabel.text = title;
        indeterminateProgress = [coverSubView viewWithTag:102];
        messageLabel = [coverSubView viewWithTag:103];
        messageLabel.text = message;
        coverSubView.translatesAutoresizingMaskIntoConstraints = YES;
        [coverSubView setFrame:CGRectMake(0, 0, [UIScreen mainScreen].bounds.size.width, [UIScreen mainScreen].bounds.size.height)];
    }
    [indeterminateProgress setProgressType:MDProgressTypeIndeterminate];
    [indeterminateProgress setProgressColor:[UIColor colorWithRed:0/255.0 green:215/255.0 blue:111/255.0 alpha:1.0]];
    [indeterminateProgress setTrackWidth:2.0];
    [indeterminateProgress setCircularSize:64.0];
    //add progressView to coverView
    [coverView addSubview:coverSubView];
    //add coverView to window
    [App_delegate.window addSubview:coverView];
}

-(void)showMDRefreshControl: (UIView*)topView {
    window = [[UIApplication sharedApplication] keyWindow];
    CGRect screenRect = topView.bounds;
    //create a new view with the same size as that of device screen
    coverView = [[UIView alloc] initWithFrame:screenRect];

    //create new progressView, set it frame, its center and its background color
    progressView = [[UIView alloc]init];
    progressView.frame = coverView.frame;
    progressView.backgroundColor = [UIColor clearColor];
    //create new MDProgressHUD, set it frame, its type and progress color
    indeterminateProgress = [[MDProgress alloc]init];
    [indeterminateProgress setFrame:CGRectMake(progressView.bounds.origin.x+130, progressView.bounds.origin.y+24, 64, 64)];
    indeterminateProgress.center = coverView.center;
    [indeterminateProgress setProgressType:MDProgressTypeIndeterminate];
    [indeterminateProgress setProgressColor:[UIColor colorWithRed:0/255.0 green:215/255.0 blue:111/255.0 alpha:1.0]];
    [indeterminateProgress setTrackWidth:2.0];
    [indeterminateProgress setCircularSize:30.0];
    
    //add MDProgressHUD to progressView
    [progressView addSubview:indeterminateProgress];
    //add progressView to coverView
    [coverView addSubview:progressView];
    //add coverView to window
    [topView addSubview:coverView];
}

-(void)showMDRefreshControl: (UIView*)topView navView:(UIView *)refreshView {
    window = [[UIApplication sharedApplication] keyWindow];
    CGRect screenRect = topView.bounds;
    //create a new view with the same size as that of device screen
    coverView = [[UIView alloc] initWithFrame:screenRect];
    // change the background color to black and the opacity to 1.0
    coverView.backgroundColor = [[UIColor whiteColor] colorWithAlphaComponent:1.0];
    //create new progressView, set it frame, its center and its background color
    UIImageView *rcImageView = [[UIImageView alloc]initWithFrame: CGRectMake(0, 0, [UIScreen mainScreen].bounds.size.width, coverView.frame.size.height)];
    rcImageView.image = [CommonMethods imageFromLayer:[CommonMethods makeGradientNavBar:rcImageView]];
    [coverView insertSubview:rcImageView atIndex:0];
    indeterminateProgress = [[MDProgress alloc]initWithFrame: CGRectMake(0, 5, 25, 25)];
    //create new MDProgressHUD, set it frame, its type and progress color
    [indeterminateProgress setProgressType:MDProgressTypeIndeterminate];
    [indeterminateProgress setProgressColor:[UIColor whiteColor]];
    indeterminateProgress.alpha = 0.65;
    [indeterminateProgress setTrackWidth: 2.0];
    [indeterminateProgress setCircularSize: 25.0];
    LocalisedLabel *messageLabel = [[LocalisedLabel alloc]initWithFrame: CGRectMake(38, 10, 149, 15)];
    messageLabel.text = [NSString localizedStringWithFormat:Fetching_Device_Status];
    messageLabel.font = [UIFont fontWithName: SFUITEXT_REGULAR size:13.0];
    messageLabel.textColor = [UIColor whiteColor];
    messageLabel.alpha = 0.65;
    progressView = [[UIView alloc]initWithFrame: CGRectMake(0, 0, 187, 35)];
    progressView.center = coverView.center;
    [progressView addSubview: messageLabel];
    //add MDProgressHUD to progressView
    [progressView addSubview: indeterminateProgress];
    //add progressView to coverView
    [coverView addSubview: progressView];
    //add coverView to window
    [topView addSubview: coverView];
}

/**
 * @method - hideMDProgressHUD
 * @description - to hide View with MDProgressHUD and a label
 * @param - none
 * @return None
 */
-(void)hideMDProgressHUD {
    //enable user interaction with window
    [window setUserInteractionEnabled:YES];
    [parentView setUserInteractionEnabled:YES];
    //remove the view that containf MDProgressHUD and label
    [coverView removeFromSuperview];
}

@end
